<?php

namespace Drupal\monarch_symlink\Entity;

use Drupal\Core\Entity\EntityStorageInterface;

/**
 * Defines the symlink entity class.
 *
 * @ContentEntityType(
 *   id = "symlink",
 *   label = @Translation("Symlink"),
 *   label_collection = @Translation("Symlinks"),
 *   label_singular = @Translation("symlink"),
 *   label_plural = @Translation("symlinks"),
 *   label_count = @PluralTranslation(
 *     singular = "@count symlink",
 *     plural = "@count symlinks"
 *   ),
 *   handlers = {
 *     "storage" = "\Drupal\menu_link_content\MenuLinkContentStorage",
 *     "storage_schema" = "Drupal\menu_link_content\MenuLinkContentStorageSchema",
 *     "view_builder" = "Drupal\Core\Entity\EntityViewBuilder",
 *     "list_builder" = "Drupal\monarch_symlink\SymlinkListBuilder",
 *     "views_data" = "Drupal\views\EntityViewsData",
 *     "access" = "Drupal\monarch_symlink\SymlinkAccessControlHandler",
 *     "form" = {
 *       "add" = "Drupal\monarch_symlink\Form\SymlinkForm",
 *       "edit" = "Drupal\monarch_symlink\Form\SymlinkForm",
 *       "delete" = "Drupal\Core\Entity\ContentEntityDeleteForm"
 *     },
 *     "route_provider" = {
 *       "html" = "Drupal\monarch_symlink\Entity\SymlinkRouteProvider",
 *     }
 *   },
 *   base_table = "symlink",
 *   revision_table = "symlink_revision",
 *   admin_permission = "administer symlinks",
 *   entity_keys = {
 *     "id" = "id",
 *     "revision" = "revision_id",
 *     "label" = "title",
 *     "langcode" = "langcode",
 *     "uuid" = "uuid",
 *     "bundle" = "bundle",
 *     "published" = "enabled",
 *   },
 *   revision_metadata_keys = {
 *     "revision_user" = "revision_user",
 *     "revision_created" = "revision_created",
 *     "revision_log_message" = "revision_log_message",
 *   },
 *   links = {
 *     "canonical" = "/symlink/{symlink}",
 *     "collection" = "/admin/structure/menu/symlink",
 *     "add-form" = "/admin/structure/menu/symlink/add",
 *     "edit-form" = "/admin/structure/menu/symlink/{symlink}/edit",
 *     "delete-form" = "/admin/structure/menu/symlink/{symlink}/delete",
 *   },
 *   constraints = {
 *     "MenuTreeHierarchy" = {}
 *   },
 * )
 */
class Symlink extends SymlinkBase {

  /**
   * {@inheritdoc}
   */
  public static function preCreate(EntityStorageInterface $storage, array &$values) {
    $values += ['bundle' => 'symlink'];
  }

  /**
   * {@inheritdoc}
   */
  public function getPluginDefinition() {
    $definition = parent::getPluginDefinition();
    $definition['class'] = 'Drupal\monarch_symlink\Plugin\Menu\SymlinkMenuItem';
    $definition['form_class'] = '\Drupal\monarch_symlink\Form\SymlinkForm';
    $definition['provider'] = 'monarch_symlink';
    return $definition;
  }

}
